nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Capctrl

Struct Capctrl 

#[repr(transparent)]
pub struct Capctrl(pub u32);
SCT capture control register

Tuple Fields

0: u32

Implementations

Source

impl Capctrl

pub const fn capconn_l(&self) -> u16

If bit m is one, event m causes the CAPn_L (UNIFY = 0) or the CAPn (UNIFY = 1) register to be loaded (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of match/captures in this SCT.

pub const fn set_capconn_l(&mut self, val: u16)

If bit m is one, event m causes the CAPn_L (UNIFY = 0) or the CAPn (UNIFY = 1) register to be loaded (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of match/captures in this SCT.

pub const fn capconn_h(&self) -> u16

If bit m is one, event m causes the CAPn_H (UNIFY = 0) register to be loaded (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of match/captures in this SCT.

pub const fn set_capconn_h(&mut self, val: u16)

If bit m is one, event m causes the CAPn_H (UNIFY = 0) register to be loaded (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of match/captures in this SCT.