#[repr(transparent)]pub struct Halt(pub u32);Expand description
SCT halt event select register
Tuple Fields
0: u32Implementations
Sourceimpl Halt
impl Halt
Sourcepub const fn haltmsk_l(&self) -> u16
pub const fn haltmsk_l(&self) -> u16
If bit n is one, event n sets the HALT_L bit in the CTRL register (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.
Sourcepub const fn set_haltmsk_l(&mut self, val: u16)
pub const fn set_haltmsk_l(&mut self, val: u16)
If bit n is one, event n sets the HALT_L bit in the CTRL register (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.
Sourcepub const fn haltmsk_h(&self) -> u16
pub const fn haltmsk_h(&self) -> u16
If bit n is one, event n sets the HALT_H bit in the CTRL register (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of events in this SCT.
Sourcepub const fn set_haltmsk_h(&mut self, val: u16)
pub const fn set_haltmsk_h(&mut self, val: u16)
If bit n is one, event n sets the HALT_H bit in the CTRL register (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of events in this SCT.